Function tuxedo_template_wallet::keystore::has_key
source · pub fn has_key(keystore: &LocalKeystore, pubkey: &H256) -> boolExpand description
Check whether a specific key is in the keystore
pub fn has_key(keystore: &LocalKeystore, pubkey: &H256) -> boolCheck whether a specific key is in the keystore